"use strict";
// Encode SVG PathData
// http://www.w3.org/TR/SVG/paths.html#PathDataBNF
Object.defineProperty(exports, "__esModule", { value: true });
var SVGPathData_1 = require("./SVGPathData");
// Private consts : Char groups
var WSP = " ";
function encodeSVGPath(commands) {
    var str = "";
    if (!Array.isArray(commands)) {
        commands = [commands];
    }
    for (var i = 0; i < commands.length; i++) {
        var command = commands[i];
        if (command.type === SVGPathData_1.SVGPathData.CLOSE_PATH) {
            str += "z";
        }
        else if (command.type === SVGPathData_1.SVGPathData.HORIZ_LINE_TO) {
            str += (command.relative ? "h" : "H") +
                command.x;
        }
        else if (command.type === SVGPathData_1.SVGPathData.VERT_LINE_TO) {
            str += (command.relative ? "v" : "V") +
                command.y;
        }
        else if (command.type === SVGPathData_1.SVGPathData.MOVE_TO) {
            str += (command.relative ? "m" : "M") +
                command.x + WSP + command.y;
        }
        else if (command.type === SVGPathData_1.SVGPathData.LINE_TO) {
            str += (command.relative ? "l" : "L") +
                command.x + WSP + command.y;
        }
        else if (command.type === SVGPathData_1.SVGPathData.CURVE_TO) {
            str += (command.relative ? "c" : "C") +
                command.x1 + WSP + command.y1 +
                WSP + command.x2 + WSP + command.y2 +
                WSP + command.x + WSP + command.y;
        }
        else if (command.type === SVGPathData_1.SVGPathData.SMOOTH_CURVE_TO) {
            str += (command.relative ? "s" : "S") +
                command.x2 + WSP + command.y2 +
                WSP + command.x + WSP + command.y;
        }
        else if (command.type === SVGPathData_1.SVGPathData.QUAD_TO) {
            str += (command.relative ? "q" : "Q") +
                command.x1 + WSP + command.y1 +
                WSP + command.x + WSP + command.y;
        }
        else if (command.type === SVGPathData_1.SVGPathData.SMOOTH_QUAD_TO) {
            str += (command.relative ? "t" : "T") +
                command.x + WSP + command.y;
        }
        else if (command.type === SVGPathData_1.SVGPathData.ARC) {
            str += (command.relative ? "a" : "A") +
                command.rX + WSP + command.rY +
                WSP + command.xRot +
                WSP + (+command.lArcFlag) + WSP + (+command.sweepFlag) +
                WSP + command.x + WSP + command.y;
        }
        else {
            // Unknown command
            throw new Error("Unexpected command type \"" + command.type + "\" at index " + i + ".");
        }
    }
    return str;
}
exports.encodeSVGPath = encodeSVGPath;
//# sourceMappingURL=SVGPathDataEncoder.js.map